
#include <zephyr.h>
#include <kernel.h>
#include <modem/lte_lc.h>
#include <logging/log.h>
#include <logging/log_backend.h>
#include <logging/log_ctrl.h>

LOG_MODULE_REGISTER(net_syslog_lte, LOG_LEVEL_DBG);

extern const struct log_backend *log_backend_net_get(void);

void begin_syslog(void)
{
  LOG_INF("Begin logging to syslog...");
  const struct log_backend *log_backend_net = log_backend_net_get();
  if (log_backend_net->api->init != NULL) {
    log_backend_net->api->init(log_backend_net);
  }
  log_backend_activate(log_backend_net, NULL);
}

void lte_connect(void)
{
  int err = lte_lc_init_and_connect();
  if (err)
  {
    LOG_ERR("Failed to connect to LTE, error: %d", err);
    return;
  }
  LOG_INF("LTE connected successfully");
}

#define SLEEP_BETWEEN_LOG_PRINTS 10 // sec
#define TOTAL_LOG_TIME 30 // sec

void cycle_logs(void)
{
  int i, count;

  /* Allow some setup time before starting to send data */
  k_sleep(K_SECONDS(SLEEP_BETWEEN_LOG_PRINTS));

  count = TOTAL_LOG_TIME / SLEEP_BETWEEN_LOG_PRINTS;
  i = count;

  do
  {
    LOG_ERR("Error message (%d)", i);
    LOG_WRN("Warning message (%d)", i);
    LOG_INF("Info message (%d)", i);
    LOG_DBG("Debug message (%d)", i);

    k_sleep(K_SECONDS(SLEEP_BETWEEN_LOG_PRINTS));

  } while (--i);

  LOG_DBG("Stopped after %d msg", count);
}

void main(void)
{

  LOG_INF("Starting application...");

  lte_connect();

  begin_syslog();

  cycle_logs();

  while (1)
  {
    k_sleep(K_SECONDS(10));
  }
}
